==> jc-1.4.0.tar.gz: soot/RefLikeType.h <==
// public abstract class soot.RefLikeType

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class fdbc627922b0ba72 soot_RefLikeType
// @dep_class f801e5c664424a1 soot_Type

// header file dependencies
// @dep_header soot_Type

#include "soot/Type.h"

#ifndef _JC_soot_RefLikeType_H_
#define _JC_soot_RefLikeType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Type$object;

// Typedefs
typedef struct _jc_soot_RefLikeType$sub_refs	_jc_soot_RefLikeType$sub_refs;
typedef struct _jc_soot_RefLikeType$sub_nonrefs	_jc_soot_RefLikeType$sub_nonrefs;
typedef struct _jc_soot_RefLikeType$refs	_jc_soot_RefLikeType$refs;
typedef struct _jc_soot_RefLikeType$nonrefs	_jc_soot_RefLikeType$nonrefs;
typedef struct _jc_soot_RefLikeType$object	_jc_soot_RefLikeType$object;

typedef const struct _jc_soot_RefLikeType$vmethods	_jc_soot_RefLikeType$vmethods;
typedef const struct _jc_soot_RefLikeType$vtable	_jc_soot_RefLikeType$vtable;
typedef const struct _jc_soot_RefLikeType$vtype	_jc_soot_RefLikeType$vtype;

// Constructors
extern void _jc_soot_RefLikeType$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_RefLikeType$object *);

// Virtual methods
extern struct _jc_soot_Type$object *_jc_soot_RefLikeType$method$getArrayElementType$15d4b254b1d62067(_jc_env *, struct _jc_soot_RefLikeType$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_RefLikeType$method_info$getArrayElementType$15d4b254b1d62067;

// Virtual methods structure
struct _jc_soot_RefLikeType$vmethods {
	struct _jc_soot_Type$object	*(*getArrayElementType$15d4b254b1d62067)(_jc_env *, struct _jc_soot_RefLikeType$object *);
};

// Vtable
struct _jc_soot_RefLikeType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Type$vmethods	soot_Type;
	_jc_soot_RefLikeType$vmethods	soot_RefLikeType;
};

// Vtype
struct _jc_soot_RefLikeType$vtype {
	_jc_type			type;
	_jc_soot_RefLikeType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_RefLikeType$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_RefLikeType$refs {
    _jc_soot_RefLikeType$sub_refs	soot_RefLikeType;
    _jc_soot_Type$sub_refs	soot_Type;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_RefLikeType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_RefLikeType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Type$sub_nonrefs	soot_Type;
    _jc_soot_RefLikeType$sub_nonrefs	soot_RefLikeType;
};

// Object instance structure
struct _jc_soot_RefLikeType$object {
	_jc_soot_RefLikeType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_RefLikeType$vtype	*vtype;
	_jc_soot_RefLikeType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_RefLikeType$vtype _jc_soot_RefLikeType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_RefLikeType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_RefLikeType$class_object;

#endif	/* _JC_soot_RefLikeType_H_ */

==> jc-1.4.6.tar.gz: soot/RefLikeType.h <==
// public abstract class soot.RefLikeType

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class fdbc627922b0ba72 soot_RefLikeType
// @dep_class f801e5c664424a1 soot_Type

// header file dependencies
// @dep_header soot_Type

#include "soot/Type.h"

#ifndef _JC_soot_RefLikeType_H_
#define _JC_soot_RefLikeType_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Type$object;

// Typedefs
typedef struct _jc_soot_RefLikeType$sub_refs	_jc_soot_RefLikeType$sub_refs;
typedef struct _jc_soot_RefLikeType$sub_nonrefs	_jc_soot_RefLikeType$sub_nonrefs;
typedef struct _jc_soot_RefLikeType$refs	_jc_soot_RefLikeType$refs;
typedef struct _jc_soot_RefLikeType$nonrefs	_jc_soot_RefLikeType$nonrefs;
typedef struct _jc_soot_RefLikeType$object	_jc_soot_RefLikeType$object;

typedef const struct _jc_soot_RefLikeType$vmethods	_jc_soot_RefLikeType$vmethods;
typedef const struct _jc_soot_RefLikeType$vtable	_jc_soot_RefLikeType$vtable;
typedef const struct _jc_soot_RefLikeType$vtype	_jc_soot_RefLikeType$vtype;

// Constructors
extern void _jc_soot_RefLikeType$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_RefLikeType$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_Type$object *_jc_soot_RefLikeType$method$getArrayElementType$15d4b254b1d62067(_jc_env *, struct _jc_soot_RefLikeType$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_RefLikeType$method_info$getArrayElementType$15d4b254b1d62067;

// Virtual methods structure
struct _jc_soot_RefLikeType$vmethods {
	struct _jc_soot_Type$object	*(*getArrayElementType$15d4b254b1d62067)(_jc_env *, struct _jc_soot_RefLikeType$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_RefLikeType$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Type$vmethods	soot_Type;
	_jc_soot_RefLikeType$vmethods	soot_RefLikeType;
};

// Vtype
struct _jc_soot_RefLikeType$vtype {
	_jc_type			type;
	_jc_soot_RefLikeType$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_RefLikeType$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_RefLikeType$refs {
    _jc_soot_RefLikeType$sub_refs	soot_RefLikeType;
    _jc_soot_Type$sub_refs	soot_Type;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_RefLikeType$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_RefLikeType$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Type$sub_nonrefs	soot_Type;
    _jc_soot_RefLikeType$sub_nonrefs	soot_RefLikeType;
};

// Object instance structure
struct _jc_soot_RefLikeType$object {
	_jc_soot_RefLikeType$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_RefLikeType$vtype	*vtype;
	_jc_soot_RefLikeType$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_RefLikeType$vtype _jc_soot_RefLikeType$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_RefLikeType, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_RefLikeType$class_object;

#endif	/* _JC_soot_RefLikeType_H_ */
